mdBook preprocessor integration.
This module provides the mdBook preprocessor that transforms exercise directives in markdown files into interactive HTML.
Structs
- Exercise
Include Processor - A more sophisticated processor that handles inline exercise includes.
- Exercises
Preprocessor - The mdBook preprocessor for exercises.
- Full
Exercises Preprocessor - Preprocessor that supports both inline exercises and include syntax.